"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunnerServiceImpl = void 0;
const constants_1 = require("@grpc/grpc-js/build/src/constants");
const path_1 = require("path");
const os_1 = require("os");
const _1 = require(".");
const messages_pb_1 = require("./gen/messages_pb");
const spec_pb_1 = require("./gen/spec_pb");
const ImplLoader_1 = require("./loaders/ImplLoader");
const StepRegistry_1 = require("./models/StepRegistry");
const CacheFileProcessor_1 = require("./processors/CacheFileProcessor");
const ExecutionEndingProcessor_1 = require("./processors/ExecutionEndingProcessor");
const ExecutionStartingProcessor_1 = require("./processors/ExecutionStartingProcessor");
const RefactorProcessor_1 = require("./processors/RefactorProcessor");
const ScenarioExecutionEndingProcessor_1 = require("./processors/ScenarioExecutionEndingProcessor");
const ScenarioExecutionStartingProcessor_1 = require("./processors/ScenarioExecutionStartingProcessor");
const SpecExecutionEndingProcessor_1 = require("./processors/SpecExecutionEndingProcessor");
const SpecExecutionStartingProcessor_1 = require("./processors/SpecExecutionStartingProcessor");
const StepExecutionEndingProcessor_1 = require("./processors/StepExecutionEndingProcessor");
const StepExecutionProcessor_1 = require("./processors/StepExecutionProcessor");
const StepExecutionStartingProcessor_1 = require("./processors/StepExecutionStartingProcessor");
const StepNameProcessor_1 = require("./processors/StepNameProcessor");
const StepPositionsProcessor_1 = require("./processors/StepPositionsProcessor");
const StubImplementationCodeProcessor_1 = require("./processors/StubImplementationCodeProcessor");
const ValidationProcessor_1 = require("./processors/ValidationProcessor");
const Util_1 = require("./utils/Util");
class RunnerServiceImpl {
    constructor(server, loader) {
        this._server = server;
        this._loader = loader;
        this._stepValidateRequestProcessor = new ValidationProcessor_1.ValidationProcessor();
        this._stepNameRequestProcessor = new StepNameProcessor_1.StepNameProcessor();
        this._refactorRequestProcessor = new RefactorProcessor_1.RefactorProcessor();
        this._cacheFileRequestProcessor = new CacheFileProcessor_1.CacheFileProcessor(this._loader);
        this._stubImplementationCodeRequestProcessor = new StubImplementationCodeProcessor_1.StubImplementationCodeProcessor();
        this._stepPositionsRequestProcessor = new StepPositionsProcessor_1.StepPositionsProcessor();
        this._executionStartingProcessor = new ExecutionStartingProcessor_1.ExecutionStartingProcessor();
        this._executionEndingProcessor = new ExecutionEndingProcessor_1.ExecutionEndingProcessor();
        this._specExecutionStartingProcessor = new SpecExecutionStartingProcessor_1.SpecExecutionStartingProcessor();
        this._specExecutionEndingProcessor = new SpecExecutionEndingProcessor_1.SpecExecutionEndingProcessor();
        this._scenarioExecutionStartingProcessor = new ScenarioExecutionStartingProcessor_1.ScenarioExecutionStartingProcessor();
        this._scenarioExecutionEndingProcessor = new ScenarioExecutionEndingProcessor_1.ScenarioExecutionEndingProcessor();
        this._stepExecutionStartingProcessor = new StepExecutionStartingProcessor_1.StepExecutionStartingProcessor();
        this._stepExecutionEndingProcessor = new StepExecutionEndingProcessor_1.StepExecutionEndingProcessor();
        this._executeStepProcessor = new StepExecutionProcessor_1.StepExecutionProcessor();
    }
    validateStep(call, callback) {
        try {
            callback(null, this._stepValidateRequestProcessor.process(call.request));
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    initializeSuiteDataStore(call, callback) {
        try {
            _1.DataStoreFactory.getSuiteDataStore().clear();
            const loader = new ImplLoader_1.ImplLoader();
            loader.loadImplementations()
                .then(() => callback(null, this.getEmptExecutionResponse()))
                .catch((err) => {
                callback(this.createRpcError(err), null);
            });
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    startExecution(call, callback) {
        this._executionStartingProcessor.process(call.request)
            .then((res) => callback(null, res))
            .catch((error) => callback(this.createRpcError(error), null));
    }
    initializeSpecDataStore(call, callback) {
        try {
            _1.DataStoreFactory.getSpecDataStore().clear();
            callback(null, this.getEmptExecutionResponse());
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    startSpecExecution(call, callback) {
        this._specExecutionStartingProcessor.process(call.request)
            .then((res) => callback(null, res))
            .catch((error) => callback(this.createRpcError(error), null));
    }
    initializeScenarioDataStore(call, callback) {
        try {
            _1.DataStoreFactory.getScenarioDataStore().clear();
            callback(null, this.getEmptExecutionResponse());
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    startScenarioExecution(call, callback) {
        this._scenarioExecutionStartingProcessor.process(call.request)
            .then((res) => callback(null, res))
            .catch((error) => callback(this.createRpcError(error), null));
    }
    startStepExecution(call, callback) {
        this._stepExecutionStartingProcessor.process(call.request)
            .then((res) => callback(null, res))
            .catch((error) => callback(this.createRpcError(error), null));
    }
    executeStep(call, callback) {
        this._executeStepProcessor.process(call.request)
            .then((res) => callback(null, res))
            .catch((error) => callback(this.createRpcError(error), null));
    }
    finishStepExecution(call, callback) {
        this._stepExecutionEndingProcessor.process(call.request)
            .then((res) => callback(null, res))
            .catch((error) => callback(this.createRpcError(error), null));
    }
    finishScenarioExecution(call, callback) {
        this._scenarioExecutionEndingProcessor.process(call.request)
            .then((res) => callback(null, res))
            .catch((error) => callback(this.createRpcError(error), null));
    }
    finishSpecExecution(call, callback) {
        this._specExecutionEndingProcessor.process(call.request)
            .then((res) => callback(null, res))
            .catch((error) => callback(this.createRpcError(error), null));
    }
    finishExecution(call, callback) {
        this._executionEndingProcessor.process(call.request)
            .then((res) => callback(null, res))
            .catch((error) => callback(this.createRpcError(error), null));
    }
    cacheFile(call, callback) {
        try {
            this._cacheFileRequestProcessor.process(call.request);
            callback(null, new messages_pb_1.Empty());
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    getStepName(call, callback) {
        try {
            callback(null, this._stepNameRequestProcessor.process(call.request));
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    getGlobPatterns(call, callback) {
        try {
            const patterns = Util_1.Util.getImplDirs().map((dir) => {
                return dir.split(path_1.sep).concat(['**', '*.ts']).join('/');
            });
            const res = new messages_pb_1.ImplementationFileGlobPatternResponse();
            res.setGlobpatternsList(patterns);
            callback(null, res);
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    getStepNames(call, callback) {
        try {
            const res = new messages_pb_1.StepNamesResponse();
            res.setStepsList(StepRegistry_1.default.getStepTexts());
            callback(null, res);
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    getStepPositions(call, callback) {
        try {
            callback(null, this._stepPositionsRequestProcessor.process(call.request));
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    getImplementationFiles(call, callback) {
        try {
            const res = new messages_pb_1.ImplementationFileListResponse();
            res.setImplementationfilepathsList(Util_1.Util.getListOfFiles());
            callback(null, res);
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    implementStub(call, callback) {
        try {
            callback(null, this._stubImplementationCodeRequestProcessor.process(call.request));
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    refactor(call, callback) {
        try {
            callback(null, this._refactorRequestProcessor.process(call.request));
        }
        catch (error) {
            callback(this.createRpcError(error), null);
        }
    }
    kill(_call, callback) {
        callback(null, new messages_pb_1.Empty());
        setTimeout(() => {
            this._server && this._server.forceShutdown();
            process.exit(0);
        }, 100);
    }
    createRpcError(error) {
        var _a, _b;
        return { code: constants_1.Status.INTERNAL, message: error.message, stack: (_a = error.stack) !== null && _a !== void 0 ? _a : '', details: `${error.message}${os_1.EOL}${(_b = error.stack) !== null && _b !== void 0 ? _b : ''}` };
    }
    getEmptExecutionResponse() {
        const res = new messages_pb_1.ExecutionStatusResponse();
        const result = new spec_pb_1.ProtoExecutionResult();
        result.setFailed(false);
        res.setExecutionresult(result);
        return res;
    }
}
exports.RunnerServiceImpl = RunnerServiceImpl;
