"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Table = void 0;
const TableRow_1 = require("./TableRow");
class Table {
    static from(table) {
        var _a;
        if (!table.getHeaders()) {
            throw new Error('Invalid table passed');
        }
        const header = table.getHeaders();
        const gaugeTable = new Table((_a = header === null || header === void 0 ? void 0 : header.getCellsList()) !== null && _a !== void 0 ? _a : []);
        table.getRowsList().forEach((row) => {
            gaugeTable.addRow(row.getCellsList());
        });
        return gaugeTable;
    }
    constructor(headers) {
        this._headers = headers;
        this._rows = new Array();
        this._tableRows = new Array();
    }
    addRow(row) {
        if (row.length != this._headers.length) {
            throw new Error(`Row size mismatch. Expected row size: ${this._headers.length}.`
                + `Obtained row size: ${row.length}.`);
        }
        this._rows.push(row);
        const tableRow = new TableRow_1.TableRow();
        for (const header of this._headers) {
            tableRow.addCell(header, row[this._headers.indexOf(header)]);
        }
        this._tableRows.push(tableRow);
    }
    getColumnNames() {
        return this._headers;
    }
    getColumnName(index) {
        if (index < 0 || index >= this._headers.length) {
            throw new Error(`Column with index ${index} not found. Actual column size: ${this._headers.length}.`);
        }
        return this._headers[index];
    }
    getTableRows() {
        return this._tableRows;
    }
    getColumnValues(columnName) {
        return this.getColumnValuesForIndex(this._headers.indexOf(columnName));
    }
    getColumnValuesForIndex(index) {
        if (index >= 0) {
            return this._rows.map((row) => row[index]);
        }
        return [];
    }
}
exports.Table = Table;
